Rev 2195: Have RemoteBzrDirFormat create a local format object when it is asked to initialize something on a non-smart transport - allowing sprout to work cleanly. in http://bazaar.launchpad.net/~bzr/bzr/hpss

Robert Collins robertc at robertcollins.net
Thu Mar 29 07:56:51 BST 2007


At http://bazaar.launchpad.net/~bzr/bzr/hpss

------------------------------------------------------------
revno: 2195
revision-id: robertc at robertcollins.net-20070329065545-e4d0sbkszqbr5p84
parent: andrew.bennetts at canonical.com-20070329064628-gdonyjmcedx7q8vh
committer: Robert Collins <robertc at robertcollins.net>
branch nick: hpss
timestamp: Thu 2007-03-29 16:55:45 +1000
message:
  Have RemoteBzrDirFormat create a local format object when it is asked to initialize something on a non-smart transport - allowing sprout to work cleanly.
modified:
  bzrlib/bzrdir.py               bzrdir.py-20060131065624-156dfea39c4387cb
=== modified file 'bzrlib/bzrdir.py'
--- a/bzrlib/bzrdir.py	2007-03-29 05:00:40 +0000
+++ b/bzrlib/bzrdir.py	2007-03-29 06:55:45 +0000
@@ -2180,8 +2180,13 @@
             return klass()
 
     def initialize_on_transport(self, transport):
-        # hand off the request to the smart server
-        medium = transport.get_smart_medium()
+        try:
+            # hand off the request to the smart server
+            medium = transport.get_smart_medium()
+        except errors.NoSmartMedium:
+            # TODO: lookup the local format from a server hint.
+            local_dir_format = BzrDirMetaFormat1()
+            return local_dir_format.initialize_on_transport(transport)
         client = SmartClient(medium)
         path = client.remote_path_from_transport(transport)
         response = SmartClient(medium).call('BzrDirFormat.initialize', path)



More information about the bazaar-commits mailing list